.. _spkg_sphinxcontrib_applehelp:

sphinxcontrib_applehelp: Sphinx extension which outputs Apple help book
=================================================================================

Description
-----------

Sphinx extension which outputs Apple help book

License
-------

BSD

Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)

Version Information
-------------------

package-version.txt::

    1.0.8

version_requirements.txt::

    sphinxcontrib_applehelp >=1.0.2


Equivalent System Packages
--------------------------

.. tab:: Arch Linux

   .. CODE-BLOCK:: bash

       $ sudo pacman -S python-sphinxcontrib-applehelp 


.. tab:: conda-forge

   .. CODE-BLOCK:: bash

       $ conda install sphinxcontrib-applehelp 


.. tab:: FreeBSD

   .. CODE-BLOCK:: bash

       $ sudo pkg install textproc/py-sphinxcontrib-applehelp 


.. tab:: Gentoo Linux

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-python/sphinxcontrib-applehelp 


.. tab:: MacPorts

   .. CODE-BLOCK:: bash

       $ sudo port install py-sphinxcontrib-applehelp 


.. tab:: openSUSE

   .. CODE-BLOCK:: bash

       $ sudo zypper install python3\$\{PYTHON_MINOR\}-sphinxcontrib-applehelp 


.. tab:: Void Linux

   .. CODE-BLOCK:: bash

       $ sudo xbps-install python3-sphinxcontrib-applehelp 



See https://repology.org/project/python:sphinxcontrib-applehelp/versions

If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then ``./configure``
will check if the system package can be used.

